#!/bin/bash
#
# source: http://user-dirs.freedesktop.org/releases/xdg-user-dirs-0.10.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='xdg-user-dirs'
softversion='0.10'
packageversion='60.2'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

chown -R root:root .

find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
      --prefix=/usr \
      --sysconfdir=/etc \
      --disable-static

make
make install DESTDIR=$dest

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ABOUT-NLS AUTHORS ChangeLog COPYING NEWS README \
$dest/usr/doc/$soft-$softversion

# Slack-desc

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

             |-----handy-ruler-------------------------------------------------|
xdg-user-dirs: xdg-user-dirs - is a tool to help manage user directories
xdg-user-dirs:
xdg-user-dirs: xdg-user-dirs is a tool to help manage "well known" user
xdg-user-dirs: directories like the the desktop folder and the music folder
xdg-user-dirs: It also handles localization (i.e. translation) of the filenames
xdg-user-dirs:
xdg-user-dirs:
xdg-user-dirs:
xdg-user-dirs:
xdg-user-dirs:
xdg-user-dirs:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
